@@ -13,13 +13,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-try:
-    # handle py34
-    import builtins
-except ImportError:
-    # and py27
-    import __builtin__ as builtins
-
 import base64
 import fixtures
 import mock
@@ -250,6 +243,29 @@ class ShellTest(utils.TestCase):
         self.run_command('flavor-show m1.uuid')
         self.assert_called('GET', '/flavors/m1.uuid')
 
+    def test_volume_type_list(self):
+        self.run_command('volume-type-list')
+        self.assert_called('GET', '/volume-types')
+
+    def test_volume_type_list_with_datastore(self):
+        cmd = ('volume-type-list --datastore_type mysql '
+               '--datastore_version_id some-version-id')
+        self.run_command(cmd)
+        self.assert_called(
+            'GET', '/datastores/mysql/versions/some-version-id/volume-types')
+
+    def test_volume_type_list_error(self):
+        cmd = 'volume-type-list --datastore_type mysql'
+        exepcted_error_msg = ('Missing argument\(s\): '
+                              'datastore_type, datastore_version_id')
+        self.assertRaisesRegexp(
+            exceptions.MissingArgs, exepcted_error_msg, self.run_command,
+            cmd)
+
+    def test_volume_type_show(self):
+        self.run_command('volume-type-show 1')
+        self.assert_called('GET', '/volume-types/1')
+
     def test_cluster_list(self):
         self.run_command('cluster-list')
         self.assert_called('GET', '/clusters')
@@ -274,6 +290,10 @@ class ShellTest(utils.TestCase):
         self.run_command('cluster-force-delete cls-1234')
         self.assert_called('DELETE', '/clusters/cls-1234')
 
+    def test_boot_fail_with_size_0(self):
+        self.assertRaises(exceptions.ValidationError, self.run_command,
+                          'create test-member-1 1 --size 0 --volume_type lvm')
+
     def test_boot(self):
         self.run_command('create test-member-1 1 --size 1 --volume_type lvm')
         self.assert_called_anytime(
@@ -470,6 +490,11 @@ class ShellTest(utils.TestCase):
         self.run_command(cmd)
         self.assert_called('POST', '/clusters/cls-1234')
 
+    def test_cluster_upgrade(self):
+        cmd = ('cluster-upgrade cls-1234 1234')
+        self.run_command(cmd)
+        self.assert_called('POST', '/clusters/cls-1234')
+
     def test_cluster_create_with_locality(self):
         cmd = ('cluster-create test-clstr2 redis 3.0 --locality=affinity '
                '--instance flavor=2,volume=1 '
@@ -667,7 +692,7 @@ class ShellTest(utils.TestCase):
         self.assert_called('GET', '/modules/4321')
 
     def test_module_create(self):
-        with mock.patch.object(builtins, 'open'):
+        with mock.patch('argparse.open'):
             return_value = b'mycontents'
             expected_contents = str(return_value.decode('utf-8'))
             mock_encode = mock.Mock(return_value=return_value)
@@ -713,6 +738,27 @@ class ShellTest(utils.TestCase):
             self.assert_called_anytime(
                 'GET', '/modules/4321/instances?include_clustered=True')
 
+    def test_module_instance_count(self):
+        with mock.patch.object(troveclient.v1.modules.Module, '__repr__',
+                               mock.Mock(return_value='4321')):
+            self.run_command('module-instance-count 4321')
+            self.assert_called(
+                'GET', '/modules/4321/instances?count_only=True')
+
+    def test_module_instance_count_clustered(self):
+        with mock.patch.object(troveclient.v1.modules.Module, '__repr__',
+                               mock.Mock(return_value='4321')):
+            self.run_command('module-instance-count 4321 --include_clustered')
+            self.assert_called(
+                'GET', '/modules/4321/instances?count_only=True&'
+                       'include_clustered=True')
+
+    def test_module_reapply(self):
+        with mock.patch.object(troveclient.v1.modules.Module, '__repr__',
+                               mock.Mock(return_value='4321')):
+            self.run_command('module-reapply 4321 --delay=5')
+            self.assert_called_anytime('PUT', '/modules/4321/instances')
+
     def test_cluster_modules(self):
         self.run_command('cluster-modules cls-1234')
         self.assert_called_anytime('GET', '/clusters/cls-1234')
@@ -734,7 +780,7 @@ class ShellTest(utils.TestCase):
     def test_module_retrieve(self):
         with mock.patch.object(troveclient.v1.modules.Module, '__getattr__',
                                mock.Mock(return_value='4321')):
-            with mock.patch.object(builtins, 'open'):
+            with mock.patch('troveclient.v1.instances.open'):
                 self.run_command('module-retrieve 1234')
                 self.assert_called(
                     'GET',
@@ -771,16 +817,6 @@ class ShellTest(utils.TestCase):
                 'incremental': False
             }})
 
-    def test_backup_copy(self):
-        self.run_command('backup-copy new_bkp bk-1234')
-        self.assert_called_anytime(
-            'POST', '/backups',
-            {'backup': {
-                'name': 'new_bkp',
-                'incremental': False,
-                'backup': {'region': None, 'id': 'bk-1234'}
-            }})
-
     def test_database_list(self):
         self.run_command('database-list 1234')
         self.assert_called('GET', '/instances/1234/databases')
